--[[
DHUD4_Warrior.lua
Copyright (c) 2006 by Markus Inger, 2006 by Caeryn Dryad, 2007-2010 by Horacio Hoyos

This file is part of DHUD4.

    DHUD4 is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    DHUD4 is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with DHUD4.  If not, see <http://www.gnu.org/licenses/>.
]]
local DHUD4 = LibStub("AceAddon-3.0"):GetAddon("DHUD4")
local L = LibStub("AceLocale-3.0"):GetLocale("DHUD4")

local MODNAME = "DHUD4_Warrior"
local DHUD4_Warrior = DHUD4:NewModule(MODNAME, DHUD4.abilities, "AceEvent-3.0")
local VERSION = tonumber(("$Rev: 39 $"):match("%d+"))

local _G = _G

local db
local OptGetter, OptSetter, ColorGetter, ColorSetter
do
	local mod = DHUD4_Warrior
	function OptGetter(info)
		local key = info[#info]
		return db[key]
	end

	function OptSetter(info, value)
		local key = info[#info]
		db[key] = value
		mod:Refresh()
	end

    function ColorGetter (info)
        local key1, key2 = info[#info-1], info[#info]
        return db[key1][key2].r, db[key1][key2].g, db[key1][key2].b
    end

    function ColorSetter (info, r, g, b)
        local key1, key2 = info[#info-1], info[#info]
        db[key1][key2].r = r
        db[key1][key2].g = g
        db[key1][key2].b = b
        mod:Refresh()
    end
end

--Local Options
local options
local function getOptions()
    if not options then
        --Options table
        options = DHUD4_Warrior:GetOptions()
        -- Add function calls
        options.arg = MODNAME
        options.get = OptGetter
        options.set = OptSetter
        options.args.enabled.get = function() return DHUD4:GetModuleEnabled(MODNAME) end
        options.args.enabled.set = function(info, value) DHUD4:SetModuleEnabled(MODNAME, value) end
        options.args.general.disabled = function() return not DHUD4:GetModuleEnabled(MODNAME) end
        options.args.general.args.colors.get = ColorGetter
		options.args.general.args.colors.set = ColorSetter
        -- Add class specifics
    	options.args.class = {
            order = 4,
            type = 'group',
            name = L["Warrior"],
            disabled = function() return not DHUD4:GetModuleEnabled(MODNAME); end,
            args = {
                sunders = {
                    type = 'toggle',
                    order = 1,
                    name = L["Sunder Armors"],
                    desc = L["Track warrior sunder armors"],
                    hidden = false,
                },
                sundersTimer = {
                    type = 'toggle',
                    order = 2,
                    name = L["Sunder Armors Timer"],
                    desc = L["Track warrior sunder armors expiration"],
                    disabled = timerDisabled,
                    hidden = false,
                },
            },
        }
	end
	return options
end


function DHUD4_Warrior:OnInitialize()

    local _, englishClass = UnitClass("player")
    if (englishClass == "WARRIOR") then
        self.defaults.profile.sunders = true
        self.defaults.profile.sundersTimer  = true
        self.db = DHUD4.db:RegisterNamespace(MODNAME, self.defaults)
        db = self.db.profile
        self.layout = false
        DHUD4_Warrior:SetColors(db.colors)
        self:SetEnabledState(DHUD4:GetModuleEnabled(MODNAME))
        DHUD4:RegisterModuleOptions(MODNAME, getOptions, L["Warrior Abilities"])
        self.side = db.side
    else
        self:SetEnabledState(false)
        DHUD4:SetModuleEnabled(MODNAME, false)
    end
end


function DHUD4_Warrior:OnEnable()

    --DHUD4:Debug("DHUD4_Warrior:OnEnable")
    if not self:IsEnabled() then return end
    if ( DHUD4:GetModuleEnabled("DHUD4_Auras") ) then
        local auras = DHUD4:GetModule("DHUD4_Auras")
        self.db.profile.side = (auras:GetSide() == "r") and "l" or "r"
    end
    self:Refresh()
    -- Listen to bar pops
	self:RegisterMessage("DHUD4_BAR")
end


function DHUD4_Warrior:OnDisable()

	self:UnregisterAllEvents()
    self:HideAll()
end


function DHUD4_Warrior:Refresh()

    --DHUD4:Debug(MODNAME, "Refresh")
    db = self.db.profile
    self.side = db.side
    self.scale = db.scale
    self.fontSize = db.fontSize
    self:_Refresh()
    if (self.layout) then
        self:SetLayout()
    else
        if UnitExists("target") then
            self:PLAYER_TARGET_CHANGED()
        else
            self:HideAll()
        end
        if ( db.sunders ) then
            self:RegisterEvent("PLAYER_TARGET_CHANGED")
            self:RegisterEvent("UNIT_AURA")
        end
    end
end


function DHUD4_Warrior:PLAYER_TARGET_CHANGED(event)

	--DHUD4:Debug("Abiities PLAYER_TARGET_CHANGED");
	if ( UnitExists("target") and db.sunders ) then
		self:UpdateDebuff("Sunder Armor", db.sundersTimer, db.tips)
    else
        self:HideAll()
	end
end


function DHUD4_Warrior:UNIT_AURA(event, who)
    --DHUD4:Debug("Druid: UNIT_AURA", who)
	if who == "target" then
		if ( db.sunders ) then
            self:UpdateDebuff("Sunder Armor", db.sundersTimer, db.tips)
        end
    end
end


function DHUD4_Warrior:SetLayout()

    self.layout = true
    self:UnregisterAllEvents()
    self:HideAll()
    if (db.sunders) then
        self:_SetLayout(3, true)
    end
end


function DHUD4_Warrior:EndLayout()

    self.layout = false
    self:Refresh()
end
